@@ -1,7 +1,8 @@
 package Code::TidyAll::Plugin::JSHint;
-$Code::TidyAll::Plugin::JSHint::VERSION = '0.23';
-use Code::TidyAll::Util qw(tempdir_simple write_file);
-use Capture::Tiny qw(capture_merged);
+$Code::TidyAll::Plugin::JSHint::VERSION = '0.24';
+use Code::TidyAll::Util qw(tempdir_simple);
+use File::Slurp::Tiny qw(write_file);
+use IPC::Run3 qw(run3);
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
@@ -32,7 +33,8 @@ sub validate_file {
     my ( $self, $file ) = @_;
 
     my $cmd = sprintf( "%s %s %s", $self->cmd, $self->argv, $file );
-    my $output = capture_merged { system($cmd) };
+    my $output;
+    run3( $cmd, \undef, \$output, \$output );
     if ( $output =~ /\S/ ) {
         $output =~ s/^$file:\s*//gm;
         die "$output\n";
@@ -49,7 +51,7 @@ __END__
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
