@@ -1,6 +1,6 @@
 package Code::TidyAll::Plugin::JSLint;
-$Code::TidyAll::Plugin::JSLint::VERSION = '0.23';
-use Capture::Tiny qw(capture_merged);
+$Code::TidyAll::Plugin::JSLint::VERSION = '0.24';
+use IPC::Run3 qw(run3);
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
@@ -10,7 +10,8 @@ sub validate_file {
     my ( $self, $file ) = @_;
 
     my $cmd = sprintf( "%s %s %s", $self->cmd, $self->argv, $file );
-    my $output = capture_merged { system($cmd) };
+    my $output;
+    run3( $cmd, \undef, \$output, \$output );
     die "$output\n" if $output !~ /is OK\./;
 }
 
@@ -24,7 +25,7 @@ __END__
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
